/*  This is to emulate another remote process also using socket io to connect.
TEST: to see if it performs the necessary self check to identify itself, as well as 
receiving all the notification and response messages */

// Import the necessary modules
import { io, Socket } from "socket.io-client";
import { checkOwnClientInfo } from "../utils/socket.utils";

class SocketClient {
    private socket: Socket;
    private receiverProfile!: any

    constructor(url: string) {
        // Connect to the serve
        this.socket = io(url);

        // Setup event listeners
        this.socket.on("connect", () => {
            console.log("Connected to server with ID:", this.socket.id);
        });

        if (this.receiverProfile) {
            checkOwnClientInfo(this.receiverProfile.id).then((data) => {
                this.socket.emit('profile', { name: 'Existing Profile',  data: data })
            })
        } else {
            this.socket.emit('profile', { name: 'New Profile', data: null })
        }

        this.socket.on(`profile`, (info) => {
            // logic here
        })


        this.socket.on("message", (data: any) => {
            console.log("Received message:", data);
        });

        this.socket.on("disconnect", () => {
            console.log("Disconnected from server");
        });
    }

    // Emit a message to the server
    public sendMessage(event: string, message: any) {
        this.socket.emit(event, message);
    }
}

// Usage example:
const client = new SocketClient("http://localhost:3000");

// Send a message
client.sendMessage("message", "Hello, server!");
